package pnc;
import java.awt.*;
import cs101.awt.ColorField;
import cs101.util.semaphore.GCS;
import cs101.util.semaphore.GraphicalSemaphore;

public
class MultiBuffer extends Buffer {
  private int size;
  private ColorField[] locations;
  private int produceIndex = 0;
  private int consumeIndex = 0;
  private Object produceLock = new Object();
  private Object consumeLock = new Object();

  public MultiBuffer(int size) {
    // setup super class instance variables
    super();
    this.read = new GCS(size, size, "Read");
    this.write = new GCS(size, 0, "Write");
    
    // setup my instance variables
    this.size = size;
    this.locations = new ColorField[size]; 

    // add display panel for buffer
    this.bufferPanel.add(this.setupBuffer());                
  }

  public void produce() {
    this.write.request();    
    synchronized (produceLock) {
      this.locations[this.produceIndex].changeState(true);
      // incriment index and wrap if needed
      if (this.size == ++this.produceIndex)
	this.produceIndex = 0;
    }
    this.read.release();
  }

  public void consume() {
    this.read.request();
    synchronized (consumeLock) {
      this.locations[this.consumeIndex].changeState(false);
      // incriment index and wrap if needed
      if (this.size == ++this.consumeIndex)
	this.consumeIndex = 0;
    }
    this.write.release();
  }

  private Panel setupBuffer() {
    
    Panel statusPanel = new Panel();

    GridBagLayout layout = new GridBagLayout();
    statusPanel.setLayout(layout);    
    GridBagConstraints con = new GridBagConstraints();    
    con.gridwidth = 1; con.gridheight=1;
    con.fill = GridBagConstraints.HORIZONTAL;
    con.weightx = 1/this.size; con.weighty = 0;
    Dimension dim = new Dimension(20,20);
    
    for (int i = 0; i < this.size; i++) {
      this.locations[i] = new ColorField(false, dim, Color.blue,
				     Color.lightGray);
      con.gridx = i; con.gridy = 0;
      layout.setConstraints(this.locations[i], con);
      statusPanel.add(this.locations[i]);          
  
    }   
    
    return statusPanel;

  }

}

